@@ -18,7 +18,7 @@ var languageNames = {
 "en-GB": "Inglés (RX)",
 "en-ZA": "Inglés (Sudáf.)",
 "eo": "Esperantu",
-"es": "Spanish",
+"es": "Castellanu",
 "et": "Estoniu",
 "eu": "Vascu",
 "fi": "Finnish",
